==> django_carpet-0.1.1-py3-none-any.whl: django_carpet/paginate.py <==
# Python
from typing import Any, TypeVar, Callable

# Django
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from django.db.models.manager import BaseManager


_Z = TypeVar("_Z")


def paginate(entries: BaseManager[Any], page_number: int, limit: int, sort: str | None, serializer: Callable, *args, **kwargs) -> dict:
    
    paginator = Paginator(entries, limit)

    try:
        page = paginator.page(page_number)
    except PageNotAnInteger:
        page = paginator.page(1)
    except EmptyPage:
        page = paginator.page(paginator.num_pages)

    return {
        "data": serializer(*args, **kwargs),
        "limit": limit,
        "page": page_number,
        "startIndex": page.start_index(),
        "hasNext": page.has_next(),
        "sort": sort,
        "total": paginator.count,
        "totalPage": paginator.num_pages,
    }


def paginate_without_serialization(entries: BaseManager[_Z], page_number: int, limit: int, sort: str | None) -> tuple[BaseManager[_Z], dict]: # type: ignore
    paginator = Paginator(entries, limit)

    try:
        page = paginator.page(page_number)
    except PageNotAnInteger:
        page = paginator.page(1)
    except EmptyPage:
        page = paginator.page(paginator.num_pages)

    return page.object_list, { # type: ignore
        "limit": limit,
        "page": page_number,
        "startIndex": page.start_index(),
        "hasNext": page.has_next(),
        "sort": sort,
        "total": paginator.count,
        "totalPage": paginator.num_pages,
    }

==> django_carpet-0.1.7-py3-none-any.whl: django_carpet/paginate.py <==
# Python
from typing import Any, TypeVar, Callable

# Django
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from django.db.models.manager import BaseManager


_Z = TypeVar("_Z")


def paginate(entries: BaseManager[Any], page_number: int, limit: int, sort: str | None, serializer: Callable, *args, **kwargs) -> dict:
    
    paginator = Paginator(entries, limit)

    try:
        page = paginator.page(page_number)
    except PageNotAnInteger:
        page = paginator.page(1)
    except EmptyPage:
        page = paginator.page(paginator.num_pages)

    return {
        "data": serializer(paginator.object_list, *args, **kwargs),
        "limit": limit,
        "page": page_number,
        "startIndex": page.start_index(),
        "hasNext": page.has_next(),
        "sort": sort,
        "total": paginator.count,
        "totalPage": paginator.num_pages,
    }


def paginate_without_serialization(entries: BaseManager[_Z], page_number: int, limit: int, sort: str | None) -> tuple[BaseManager[_Z], dict]: # type: ignore
    paginator = Paginator(entries, limit)

    try:
        page = paginator.page(page_number)
    except PageNotAnInteger:
        page = paginator.page(1)
    except EmptyPage:
        page = paginator.page(paginator.num_pages)

    return page.object_list, { # type: ignore
        "limit": limit,
        "page": page_number,
        "startIndex": page.start_index(),
        "hasNext": page.has_next(),
        "sort": sort,
        "total": paginator.count,
        "totalPage": paginator.num_pages,
    }
